@@ -1,7 +1,8 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* pkg_depends.h - the opkg package management system
 
    Steven M. Ayer
-   
+
    Copyright (C) 2002 Compaq Computer Corporation
 
    This program is free software; you can redistribute it and/or
@@ -18,6 +19,10 @@
 #ifndef PKG_DEPENDS_H
 #define PKG_DEPENDS_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "pkg.h"
 #include "pkg_hash.h"
 
@@ -41,17 +46,17 @@ enum version_constraint {
 };
 typedef enum version_constraint version_constraint_t;
 
-struct depend{
+struct depend {
     version_constraint_t constraint;
-    char * version;
-    abstract_pkg_t * pkg;
+    char *version;
+    abstract_pkg_t *pkg;
 };
 typedef struct depend depend_t;
-    
-struct compound_depend{
+
+struct compound_depend {
     depend_type_t type;
     int possibility_count;
-    struct depend ** possibilities;
+    struct depend **possibilities;
 };
 typedef struct compound_depend compound_depend_t;
 
@@ -64,27 +69,37 @@ void buildDepends(pkg_t * pkg);
  * pkg_replaces returns 1 if pkg->replaces contains one of replacee's provides and 0
  * otherwise.
  */
-int pkg_replaces(pkg_t *pkg, pkg_t *replacee);
+int pkg_replaces(pkg_t * pkg, pkg_t * replacee);
 
 /**
  * pkg_conflicts_abstract returns 1 if pkg->conflicts contains conflictee provides and 0
  * otherwise.
  */
-int pkg_conflicts_abstract(pkg_t *pkg, abstract_pkg_t *conflicts);
+int pkg_conflicts_abstract(pkg_t * pkg, abstract_pkg_t * conflicts);
 
 /**
  * pkg_conflicts returns 1 if pkg->conflicts contains one of conflictee's provides and 0
  * otherwise.
  */
-int pkg_conflicts(pkg_t *pkg, pkg_t *conflicts);
+int pkg_conflicts(pkg_t * pkg, pkg_t * conflicts);
 
-char *pkg_depend_str(pkg_t *pkg, int index);
+int pkg_breaks_reverse_dep(pkg_t * pkg);
+
+char *pkg_depend_str(pkg_t * pkg, int index);
 void buildDependedUponBy(pkg_t * pkg, abstract_pkg_t * ab_pkg);
 int version_constraints_satisfied(depend_t * depends, pkg_t * pkg);
-int pkg_hash_fetch_unsatisfied_dependencies(pkg_t * pkg, pkg_vec_t *depends, char *** unresolved);
-pkg_vec_t * pkg_hash_fetch_conflicts(pkg_t * pkg);
-int pkg_dependence_satisfiable(depend_t *depend);
-int pkg_dependence_satisfied(depend_t *depend);
-const char* constraint_to_str(enum version_constraint c);
+int pkg_hash_fetch_unsatisfied_dependencies(pkg_t * pkg,
+                                            pkg_vec_t * depends,
+                                            char ***unresolved);
+pkg_vec_t *pkg_hash_fetch_satisfied_dependencies(pkg_t * pkg);
+pkg_vec_t *pkg_hash_fetch_conflicts(pkg_t * pkg);
+int pkg_dependence_satisfiable(depend_t * depend);
+int pkg_dependence_satisfied(depend_t * depend);
+const char *constraint_to_str(enum version_constraint c);
+enum version_constraint str_to_constraint(const char **str);
+int is_pkg_in_pkg_vec(pkg_vec_t * vec, pkg_t * pkg);
 
+#ifdef __cplusplus
+}
 #endif
+#endif                          /* PKG_DEPENDS_H */
